{ splform - How to use the splitter class

    Written by Alfons Hoogervorst.
    No copyrights claimed. Donated to the public domain.

    Last modifications July/August 1995
}

unit Splform;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Splitter, StdCtrls, Menus;

type
  TSplitterBrushType = (sbDefault, sbHatched, sbDashed, sbEllipses);

  TForm3 = class(TForm)
    ListBox1: TListBox;
    ListBox2: TListBox;
    Splitter1: TSplitter;
    Splitter2: TSplitter;
    Memo1: TMemo;
    PopupMenu1: TPopupMenu;
    Ellipses1: TMenuItem;
    Dashedlines1: TMenuItem;
    Hatchedbrush1: TMenuItem;
    Default1: TMenuItem;
    procedure Splitter2Change(Sender: TObject; OffsX, OffsY: Integer);
    procedure Splitter1Change(Sender: TObject; OffsX, OffsY: Integer);
    procedure Splitter2SplitBrush(Sender: TObject; BrushCanvas: TCanvas;
      var SplitBarWidth: Integer);
    procedure Splitter2Paint(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure FormCreate(Sender: TObject);
    procedure ChangeSplitterBrush(Sender: TObject);
  private
    { Private declarations }
    BrushType: TSplitterBrushType;
    procedure SetBrushType(bt: TSplitterBrushType);
  public
    { Public declarations }
  end;

var
  Form3: TForm3;

implementation

{$R *.DFM}

procedure TForm3.Splitter2Change(Sender: TObject; OffsX, OffsY: Integer);
begin
  with Sender as TSplitter do
  begin
    { ListBox1 changes height }
    ListBox1.Height := ListBox1.Height + OffsY;
    ListBox2.Height := ListBox2.Height + OffsY;
    Splitter1.Height := Splitter1.Height + OffsY;

    { ListBox3 moves }
    Memo1.Top := Memo1.Top + OffsY;
    Memo1.Height := Memo1.Height - OffsY;
  end;
end;

procedure TForm3.Splitter1Change(Sender: TObject; OffsX, OffsY: Integer);
begin
  with (Sender as TSplitter) do
  begin
    ListBox1.Width := ListBox1.Width + OffsX;
    ListBox2.Left := ListBox2.Left + OffsX;
    ListBox2.Width := ListBox2.Width - OffsX;
  end;
end;

procedure TForm3.Splitter2SplitBrush(Sender: TObject; BrushCanvas: TCanvas;
  var SplitBarWidth: Integer);
begin
  with (Sender as TSplitter) do
  begin
    case BrushType of

      sbDefault: ;

      sbHatched:
      begin
        BrushCanvas.Pen.Style := psClear;
        BrushCanvas.Brush.Style := bsDiagCross;
        BrushCanvas.Brush.Color := clBlack;
        BrushCanvas.Rectangle(0, 0, 8, 8);
      end;

      sbDashed:
      begin
        BrushCanvas.Pen.Width := 3;
        if Orientation = orHorizontal then
        begin
          BrushCanvas.MoveTo(0, 4);
          BrushCanvas.LineTo(4, 4);
        end else
        begin
          BrushCanvas.MoveTo(4, 0);
          BrushCanvas.LineTo(4, 4);
        end
      end;

      sbEllipses:
      begin
        BrushCanvas.Brush.Color := clBlack;
        BrushCanvas.Ellipse(1, 1, 7, 7);
      end;
    end;
  end
end;

procedure TForm3.Splitter2Paint(Sender: TObject);
begin
  with (Sender as TSplitter) do
  begin
    Canvas.Brush.Color := clPurple;
    Canvas.Ellipse(0, 0, Width, Height);
  end;
end;

procedure TForm3.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if ssCtrl in Shift then
  begin
    if (Key in [VK_UP, VK_DOWN]) then
      if not Splitter2.Splitting then
        Splitter2.DraggingStarts(False)
      else
        if key = VK_UP then
          Splitter2.DraggingToOffset(0, -5)
        else
          Splitter2.DraggingTOOffset(0, 5)
  end
  else if (Splitter2.Splitting) then
    case Key of
      VK_RETURN: Splitter2.DraggingEnds(Key = VK_ESCAPE);
      VK_ESCAPE: Splitter2.DraggingEnds(Key = VK_ESCAPE);
    end;
end;

procedure TForm3.FormCreate(Sender: TObject);
begin
  SetBrushType(BrushTYpe);
end;

procedure TForm3.SetBrushType(bt: TSplitterBrushType);
var
  i: TSplitterBrushType;
begin
  BrushType := bt;
  for i := sbDefault to sbEllipses do
  begin
    if PopupMenu1.Items[Integer(i)].Tag = Longint(bt) then
      PopupMenu1.Items[Integer(i)].Checked := True
    else PopupMenu1.Items[Integer(i)].Checked := False
  end;

  { Recreate splitters }
  Splitter1.Recreate;
  Splitter2.Recreate
end;

procedure TForm3.ChangeSplitterBrush(Sender: TObject);
begin
  SetBrushType(TSplitterBrushType((Sender as TMenuItem).Tag));
end;

end.
